@@ -7,6 +7,7 @@ from .response import Response
 from .factor import Factor
 from .analysis import Analysis
 from .optimizer import Optimizer
+from .node import Node
 
 logging.basicConfig(format="%(levelname)s: %(message)s", level=logging.INFO)
 
@@ -26,10 +27,14 @@ class SEClient:
         self.connect()
 
     def connect(self):
-        context = zmq.Context()
-        self.socket = context.socket(zmq.REQ)
+        self.context = zmq.Context()
+        self.socket = self.context.socket(zmq.REQ)
         self.socket.connect(self.SERVER_ENDPOINT)
 
+    def close(self):
+        self.socket.close()
+        self.context.term()
+
     def status_ok(self, reply):
         return reply.get('status', 500) < 400
 
@@ -111,7 +116,7 @@ class SEClient:
         })
         return result['payload']['preference']
 
-    def go_to_node(self, node, analysis_name):
+    def go_to_node(self, node : Node, analysis_name = ''):
         self.send_payload({
             "method": "POST",
             "uri": "nodes",
@@ -133,6 +138,16 @@ class SEClient:
             "path": path,
         })
 
+    def has_open_design(self):
+        result = self.send_payload({
+            "method": "GET",
+            "uri": "has_open_design",
+        })
+        is_open = result['payload']['has_open_design']
+        if is_open == "False":
+            return False
+        return True
+
     def list_analyses(self):
         result = self.send_payload({
             "method": "GET",
@@ -142,7 +157,14 @@ class SEClient:
         return result['payload']['analyses']
 
     def get_analysis(self, name):
-        return Analysis(self, name)
+        if not self.has_open_design():
+            raise HTTPException("Received error from Stat-Ease 360: {}".format("There is no design loaded."), status=404)
+
+        analyses = self.list_analyses()
+        if not name in analyses:
+            raise HTTPException("Received error from Stat-Ease 360: {}".format(f"There is no analysis named '{name}' in open design."), status=404)
+
+        return Analysis(self, name)     
 
     def get_optimizer(self):
         return Optimizer(self)
